@@ -26,7 +26,7 @@ def _query_authoritative_ns(domain, log=lambda msg: None):
                 sys.stderr.write(sub + " does not exist, skipping\n")
                 continue
             else:
-                raise Exception('%s does not exist.' % sub)
+                raise DoesNotExist('%s does not exist.' % sub)
         else:
             raise Exception('Error %s' % (dns.rcode.to_text(rcode)))
 
@@ -87,5 +87,9 @@ def main():
         print('Authoritative answer:', r)
 
 
+class DoesNotExist(Exception):
+    pass
+
+
 if __name__ == "__main__":
     main()
